-
-
-
-
-
-
-
-
-
-
- No Record
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+ No Record
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
-
diff --git a/NKC_WF/WebUserControls/cmp_MU_carts.ascx.cs b/NKC_WF/WebUserControls/cmp_MU_carts.ascx.cs
index 4bb41fe..8eada11 100644
--- a/NKC_WF/WebUserControls/cmp_MU_carts.ascx.cs
+++ b/NKC_WF/WebUserControls/cmp_MU_carts.ascx.cs
@@ -1,8 +1,10 @@
-using System;
+using AppData;
+using NKC_SDK;
+using System;
namespace NKC_WF.WebUserControls
{
- public partial class cmp_MU_carts : System.Web.UI.UserControl
+ public partial class cmp_MU_carts : BaseUserControl
{
///
/// Batch corrente...
@@ -38,6 +40,62 @@ namespace NKC_WF.WebUserControls
}
}
///
+ /// Dimensione QRCode
+ ///
+ public int qrSize
+ {
+ get
+ {
+ int answ = 32;
+ int.TryParse(hfQrSize.Value, out answ);
+ return answ;
+ }
+ set
+ {
+ hfQrSize.Value = value.ToString();
+ doUpdate();
+ }
+ }
+ ///
+ /// Indica se mostrare o meno button PRINT
+ ///
+ public bool ShowPrint
+ {
+ set
+ {
+ hfShowPrint.Value = value.ToString();
+ }
+ get
+ {
+ bool answ = false;
+ bool.TryParse(hfShowPrint.Value, out answ);
+ return answ;
+ }
+ }
+ ///
+ /// CartId selezionato
+ ///
+ public int selCartId
+ {
+ get
+ {
+ int answ = 0;
+ int.TryParse(grView.SelectedValue.ToString(), out answ);
+ return answ;
+ }
+ }
+ ///
+ /// Stampante associata
+ ///
+ protected string printer
+ {
+ get
+ {
+ string answ = DataLayer.man.getPrinter("PC-MACHINE-UNLOAD");
+ return answ;
+ }
+ }
+ ///
/// restituisce URL immagine QRCode
///
///
@@ -96,21 +154,48 @@ namespace NKC_WF.WebUserControls
return answ;
}
///
- /// Dimensione QRCode
+ /// Alla selezione mando in stampa il singolo record
///
- public int qrSize
+ ///
+ ///
+ protected void grView_SelectedIndexChanged(object sender, EventArgs e)
{
- get
+ // invio SINGOLO record in stampa
+ DataLayer.man.stampaDoc(selCartId.ToString(), printer, tipoDocumento.docCart, Request.UserHostName);
+ // reset
+ doReset();
+ }
+ ///
+ /// comando reset
+ ///
+ ///
+ ///
+ protected void lbtPrintAll_Click(object sender, EventArgs e)
+ {
+ // chiamo stored x stampare OGNI cart del BATCH
+ var tabCarts = DataLayer.man.taCR.getByBatch(BatchId);
+ try
{
- int answ = 32;
- int.TryParse(hfQrSize.Value, out answ);
- return answ;
- }
- set
- {
- hfQrSize.Value = value.ToString();
- doUpdate();
+ if (tabCarts != null && tabCarts.Count > 0)
+ {
+ foreach (var item in tabCarts)
+ {
+ // invio SINGOLO record in stampa
+ DataLayer.man.stampaDoc(item.CartID.ToString(), printer, tipoDocumento.docCart, Request.UserHostName);
+ }
+ }
}
+ catch
+ { }
+ // reset
+ doReset();
+ }
+
+ private void doReset()
+ {
+ // resetto
+ grView.SelectedIndex = -1;
+ grView.DataBind();
}
}
}
\ No newline at end of file
diff --git a/NKC_WF/WebUserControls/cmp_labelsPrint.ascx b/NKC_WF/WebUserControls/cmp_labelsPrint.ascx
new file mode 100644
index 0000000..f6f418a
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_labelsPrint.ascx
@@ -0,0 +1 @@
+<%@ Control Language="C#" AutoEventWireup="true" CodeBehind="cmp_labelsPrint.ascx.cs" Inherits="NKC_WF.WebUserControls.cmp_labelsPrint" %>
diff --git a/NKC_WF/WebUserControls/cmp_labelsPrint.ascx.cs b/NKC_WF/WebUserControls/cmp_labelsPrint.ascx.cs
new file mode 100644
index 0000000..5c2653d
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_labelsPrint.ascx.cs
@@ -0,0 +1,17 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Web;
+using System.Web.UI;
+using System.Web.UI.WebControls;
+
+namespace NKC_WF.WebUserControls
+{
+ public partial class cmp_labelsPrint : System.Web.UI.UserControl
+ {
+ protected void Page_Load(object sender, EventArgs e)
+ {
+
+ }
+ }
+}
\ No newline at end of file
diff --git a/NKC_WF/WebUserControls/cmp_labelsPrint.ascx.designer.cs b/NKC_WF/WebUserControls/cmp_labelsPrint.ascx.designer.cs
new file mode 100644
index 0000000..7ba9b15
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_labelsPrint.ascx.designer.cs
@@ -0,0 +1,17 @@
+//------------------------------------------------------------------------------
+//
+// Codice generato da uno strumento.
+//
+// Le modifiche a questo file possono causare un comportamento non corretto e verranno perse se
+// il codice viene rigenerato.
+//
+//------------------------------------------------------------------------------
+
+namespace NKC_WF.WebUserControls
+{
+
+
+ public partial class cmp_labelsPrint
+ {
+ }
+}
diff --git a/NKC_WF/WebUserControls/cmp_orderPrint.ascx b/NKC_WF/WebUserControls/cmp_orderPrint.ascx
new file mode 100644
index 0000000..a2050a9
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_orderPrint.ascx
@@ -0,0 +1,17 @@
+<%@ Control Language="C#" AutoEventWireup="true" CodeBehind="cmp_orderPrint.ascx.cs" Inherits="NKC_WF.WebUserControls.cmp_orderPrint" %>
+<%@ Register Src="~/WebUserControls/cmp_MU_bins.ascx" TagPrefix="uc1" TagName="cmp_MU_bins" %>
+<%@ Register Src="~/WebUserControls/cmp_MU_carts.ascx" TagPrefix="uc1" TagName="cmp_MU_carts" %>
+
+
+
+
+
+
+
diff --git a/NKC_WF/WebUserControls/cmp_orderPrint.ascx.cs b/NKC_WF/WebUserControls/cmp_orderPrint.ascx.cs
new file mode 100644
index 0000000..5418fb7
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_orderPrint.ascx.cs
@@ -0,0 +1,38 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Web;
+using System.Web.UI;
+using System.Web.UI.WebControls;
+
+namespace NKC_WF.WebUserControls
+{
+ public partial class cmp_orderPrint : BaseUserControl
+ {
+ protected void Page_Load(object sender, EventArgs e)
+ {
+ if(!Page.IsPostBack)
+ {
+ }
+ }
+
+ ///
+ /// BatchId corrente...
+ ///
+ public int BatchId
+ {
+ set
+ {
+ hfBatchID.Value = value.ToString();
+ cmp_MU_bins.BatchId = value;
+ cmp_MU_carts.BatchId = value;
+ }
+ get
+ {
+ int answ = 0;
+ int.TryParse(hfBatchID.Value, out answ);
+ return answ;
+ }
+ }
+ }
+}
\ No newline at end of file
diff --git a/NKC_WF/WebUserControls/cmp_orderPrint.ascx.designer.cs b/NKC_WF/WebUserControls/cmp_orderPrint.ascx.designer.cs
new file mode 100644
index 0000000..0f076a3
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_orderPrint.ascx.designer.cs
@@ -0,0 +1,44 @@
+//------------------------------------------------------------------------------
+//
+// Codice generato da uno strumento.
+//
+// Le modifiche a questo file possono causare un comportamento non corretto e verranno perse se
+// il codice viene rigenerato.
+//
+//------------------------------------------------------------------------------
+
+namespace NKC_WF.WebUserControls
+{
+
+
+ public partial class cmp_orderPrint
+ {
+
+ ///
+ /// Controllo hfBatchID.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::System.Web.UI.WebControls.HiddenField hfBatchID;
+
+ ///
+ /// Controllo cmp_MU_bins.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_MU_bins cmp_MU_bins;
+
+ ///
+ /// Controllo cmp_MU_carts.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_MU_carts cmp_MU_carts;
+ }
+}
diff --git a/NKC_WF/WebUserControls/cmp_orderRunning.ascx b/NKC_WF/WebUserControls/cmp_orderRunning.ascx
index 3ad669b..dffe19a 100644
--- a/NKC_WF/WebUserControls/cmp_orderRunning.ascx
+++ b/NKC_WF/WebUserControls/cmp_orderRunning.ascx
@@ -2,7 +2,7 @@
<%: traduci("RunningOrders") %>
-
+
@@ -11,8 +11,25 @@
<%# traduci("NoRunningOrders") %>
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/NKC_WF/WebUserControls/cmp_orderRunning.ascx.cs b/NKC_WF/WebUserControls/cmp_orderRunning.ascx.cs
index 6ecf508..2d0e6e3 100644
--- a/NKC_WF/WebUserControls/cmp_orderRunning.ascx.cs
+++ b/NKC_WF/WebUserControls/cmp_orderRunning.ascx.cs
@@ -7,6 +7,34 @@ namespace NKC_WF.WebUserControls
protected void Page_Load(object sender, EventArgs e)
{
}
+ ///
+ /// comando reset
+ ///
+ ///
+ ///
+ protected void lbtReset_Click(object sender, EventArgs e)
+ {
+ grView.SelectedIndex = -1;
+ grView.DataBind();
+ raiseReset();
+ }
+
+ protected void grView_SelectedIndexChanged(object sender, EventArgs e)
+ {
+ raiseEvent();
+ }
+ ///
+ /// BatchId selezionato
+ ///
+ public int selBatchId
+ {
+ get
+ {
+ int answ = 0;
+ int.TryParse(grView.SelectedValue.ToString(), out answ);
+ return answ;
+ }
+ }
}
}
\ No newline at end of file
diff --git a/NKC_WF/WebUserControls/cmp_orderSched.ascx b/NKC_WF/WebUserControls/cmp_orderSched.ascx
index f81a875..c8d12a1 100644
--- a/NKC_WF/WebUserControls/cmp_orderSched.ascx
+++ b/NKC_WF/WebUserControls/cmp_orderSched.ascx
@@ -2,7 +2,7 @@
<%: traduci("ScheduledOrders") %>
-
+
@@ -11,6 +11,18 @@
<%# traduci("NoScheduledOrders") %>
+
+
+
+
+
+
+
+
@@ -19,6 +31,10 @@
+
+
+
+
diff --git a/NKC_WF/WebUserControls/cmp_orderSched.ascx.cs b/NKC_WF/WebUserControls/cmp_orderSched.ascx.cs
index e9418f3..955c668 100644
--- a/NKC_WF/WebUserControls/cmp_orderSched.ascx.cs
+++ b/NKC_WF/WebUserControls/cmp_orderSched.ascx.cs
@@ -88,6 +88,33 @@ namespace NKC_WF.WebUserControls
}
return answ;
}
+ ///
+ /// comando reset
+ ///
+ ///
+ ///
+ protected void lbtReset_Click(object sender, EventArgs e)
+ {
+ grView.SelectedIndex = -1;
+ grView.DataBind();
+ raiseReset();
+ }
+ protected void grView_SelectedIndexChanged(object sender, EventArgs e)
+ {
+ raiseEvent();
+ }
+ ///
+ /// BatchId selezionato
+ ///
+ public int selBatchId
+ {
+ get
+ {
+ int answ = 0;
+ int.TryParse(grView.SelectedValue.ToString(), out answ);
+ return answ;
+ }
+ }
}
}
\ No newline at end of file
diff --git a/NKC_WF/site/DBG_QRCode_Unload.aspx.cs b/NKC_WF/site/DBG_QRCode_Unload.aspx.cs
index 6ca375b..257015f 100644
--- a/NKC_WF/site/DBG_QRCode_Unload.aspx.cs
+++ b/NKC_WF/site/DBG_QRCode_Unload.aspx.cs
@@ -29,9 +29,10 @@ namespace NKC_WF.site
int.TryParse(hfBatchID.Value, out answ);
return answ;
}
- }///
- /// SheetId corrente...
- ///
+ }
+ ///
+ /// SheetId corrente...
+ ///
public int SheetId
{
set
diff --git a/NKC_WF/site/LabelsPrint.aspx.designer.cs b/NKC_WF/site/LabelsPrint.aspx.designer.cs
index a99b040..3365442 100644
--- a/NKC_WF/site/LabelsPrint.aspx.designer.cs
+++ b/NKC_WF/site/LabelsPrint.aspx.designer.cs
@@ -11,16 +11,7 @@ namespace NKC_WF.site
{
- public partial class LabelsPrint
- {
-
- ///
- /// Controllo tpl_WIP.
- ///
- ///
- /// Campo generato automaticamente.
- /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
- ///
- protected global::NKC_WF.WebUserControls.tpl_WIP tpl_WIP;
- }
+ public partial class LabelsPrint
+ {
+ }
}
diff --git a/NKC_WF/site/OrderScheduler.aspx b/NKC_WF/site/OrderScheduler.aspx
index a039641..b8f6cfe 100644
--- a/NKC_WF/site/OrderScheduler.aspx
+++ b/NKC_WF/site/OrderScheduler.aspx
@@ -2,6 +2,8 @@
<%@ Register Src="~/WebUserControls/cmp_orderSched.ascx" TagPrefix="uc1" TagName="cmp_orderSched" %>
<%@ Register Src="~/WebUserControls/cmp_orderRunning.ascx" TagPrefix="uc1" TagName="cmp_orderRunning" %>
+<%@ Register Src="~/WebUserControls/cmp_orderPrint.ascx" TagPrefix="uc1" TagName="cmp_orderPrint" %>
+
@@ -13,9 +15,13 @@
diff --git a/NKC_WF/site/OrderScheduler.aspx.cs b/NKC_WF/site/OrderScheduler.aspx.cs
index 2644c20..c24477a 100644
--- a/NKC_WF/site/OrderScheduler.aspx.cs
+++ b/NKC_WF/site/OrderScheduler.aspx.cs
@@ -6,7 +6,39 @@ namespace NKC_WF.site
{
protected void Page_Load(object sender, EventArgs e)
{
+ if(!Page.IsPostBack)
+ {
+ cmp_orderPrintRun.Visible = false;
+ cmp_orderPrintSch.Visible = false;
+ }
+ cmp_orderRunning.eh_doRefresh += cmp_orderRunning_eh_doRefresh;
+ cmp_orderRunning.eh_doReset += cmp_orderRunning_eh_doReset;
+ cmp_orderSched.eh_doRefresh += cmp_orderSched_eh_doRefresh;
+ cmp_orderSched.eh_doReset += cmp_orderSched_eh_doReset;
+ }
+ private void cmp_orderSched_eh_doReset(object sender, EventArgs e)
+ {
+ cmp_orderPrintSch.BatchId = 0;
+ cmp_orderPrintSch.Visible = false;
+ }
+
+ private void cmp_orderSched_eh_doRefresh(object sender, EventArgs e)
+ {
+ cmp_orderPrintSch.BatchId = cmp_orderSched.selBatchId;
+ cmp_orderPrintSch.Visible = true;
+ }
+
+ private void cmp_orderRunning_eh_doReset(object sender, EventArgs e)
+ {
+ cmp_orderPrintRun.BatchId = 0;
+ cmp_orderPrintRun.Visible = false;
+ }
+
+ private void cmp_orderRunning_eh_doRefresh(object sender, EventArgs e)
+ {
+ cmp_orderPrintRun.BatchId = cmp_orderRunning.selBatchId;
+ cmp_orderPrintRun.Visible = true;
}
}
}
\ No newline at end of file
diff --git a/NKC_WF/site/OrderScheduler.aspx.designer.cs b/NKC_WF/site/OrderScheduler.aspx.designer.cs
index a2e7465..d4b0df8 100644
--- a/NKC_WF/site/OrderScheduler.aspx.designer.cs
+++ b/NKC_WF/site/OrderScheduler.aspx.designer.cs
@@ -23,6 +23,15 @@ namespace NKC_WF.site
///
protected global::NKC_WF.WebUserControls.cmp_orderRunning cmp_orderRunning;
+ ///
+ /// Controllo cmp_orderPrintRun.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_orderPrint cmp_orderPrintRun;
+
///
/// Controllo cmp_orderSched.
///
@@ -31,5 +40,14 @@ namespace NKC_WF.site
/// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
///
protected global::NKC_WF.WebUserControls.cmp_orderSched cmp_orderSched;
+
+ ///
+ /// Controllo cmp_orderPrintSch.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_orderPrint cmp_orderPrintSch;
}
}
diff --git a/NKC_WF/WebUserControls/cmp_MU_carts.ascx.designer.cs b/NKC_WF/WebUserControls/cmp_MU_carts.ascx.designer.cs
index 238cb60..c56d599 100644
--- a/NKC_WF/WebUserControls/cmp_MU_carts.ascx.designer.cs
+++ b/NKC_WF/WebUserControls/cmp_MU_carts.ascx.designer.cs
@@ -11,52 +11,61 @@ namespace NKC_WF.WebUserControls
{
- public partial class cmp_MU_carts
- {
+ public partial class cmp_MU_carts
+ {
- ///
- /// Controllo grView.
- ///
- ///
- /// Campo generato automaticamente.
- /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
- ///
- protected global::System.Web.UI.WebControls.GridView grView;
+ ///
+ /// Controllo grView.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::System.Web.UI.WebControls.GridView grView;
- ///
- /// Controllo ods.
- ///
- ///
- /// Campo generato automaticamente.
- /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
- ///
- protected global::System.Web.UI.WebControls.ObjectDataSource ods;
+ ///
+ /// Controllo ods.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::System.Web.UI.WebControls.ObjectDataSource ods;
- ///
- /// Controllo hfBatchID.
- ///
- ///
- /// Campo generato automaticamente.
- /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
- ///
- protected global::System.Web.UI.WebControls.HiddenField hfBatchID;
+ ///
+ /// Controllo hfBatchID.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::System.Web.UI.WebControls.HiddenField hfBatchID;
- ///
- /// Controllo hfShowQr.
- ///
- ///
- /// Campo generato automaticamente.
- /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
- ///
- protected global::System.Web.UI.WebControls.HiddenField hfShowQr;
+ ///
+ /// Controllo hfShowQr.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::System.Web.UI.WebControls.HiddenField hfShowQr;
- ///
- /// Controllo hfQrSize.
- ///
- ///
- /// Campo generato automaticamente.
- /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
- ///
- protected global::System.Web.UI.WebControls.HiddenField hfQrSize;
- }
+ ///
+ /// Controllo hfQrSize.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::System.Web.UI.WebControls.HiddenField hfQrSize;
+
+ ///
+ /// Controllo hfShowPrint.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::System.Web.UI.WebControls.HiddenField hfShowPrint;
+ }
}